# Framalytics 

Framalytics is a Python package to work with the Functional Resonance Analysis Method (FRAM).

Our goal is to bring FRAM to Python, enabling the interaction of FRAM models with data science
and machine learning tools. Framalytics can load FRAM models from `.xfmv` files created through
the [FRAM Model Visualizer](https://functionalresonance.com/the%20fram%20model%20visualiser/).
Components of the FRAM models can be extracted, such as list of functions, or which functions
are connected together via which aspect.

Models can be visualized directly inside a Jupyter notebook environment, reproducing the visual
style of the FMV. 

Real data can also be integrated with the FRAM model visualizations.


# Documentation

Framalytics documentation is hosted on 
[https://framalytics.readthedocs.io](https://framalytics.readthedocs.io).